# 第三方接入游戏API文档

**简介**:ASTAR视讯游戏对接文档

**联系人**:ASTAR

**Version**:3.0

**描述**:<p>由平台方提服务地址以及API接口,供第三方接入使用</p>

**准备工作**

1. 商务对接，获取渠道编码(channel)以及密钥(apiKey).
2. 加入Telegram对接群以便获取实时帮助和支持.

**接入流程**

1. **鉴权**:使用提供的渠道编码(channel)和密钥(apiKey)进行鉴权，确保请求的合法性.
2. **创建用户**:在游戏平台上创建用户账号，通常需要提供一些必要的用户信息.
3. **登录游戏**:使用创建的用户账号进行游戏登录，获取登录游戏的地址.
4. **存款(上分)**:用户在游戏中进行充值或存款操作，上分到游戏账户.
5. **进行游戏**:用户进行游戏操作，根据游戏规则进行游戏.
6. **取款(下分)**:用户将游戏中的奖金或余额提取到平台账户，下分操作.
7. **拉取注单**:获取用户在游戏中的下注记录，用于后续的数据统计和分析.

## 鉴权

**请求方式**:`GET`

**地址**:`https://<server>/channelApi/V3/API/{channel}/auth?apiKey={apiKey}`

**描述**:<p>供接入方调用,获得安全令牌(token),**填入请求头部后即可访问后续接口(每次获取的token相同,请求一次即可)**,

HTTP请求头部需要增加Authorization参数,Authorization:Bearer+空格+token,无Authorization参数:HTTP-400错误,Authorization参数错误:HTTP-403错误</p>

**代码示例**:

```javascript
{
    HttpHeaders headers = new HttpHeaders();
	headers.setBearerAuth(token);
    //同headers.setBearerAuth(token);
    //headers.add("Authorization", "Bearer " + token);
    headers.setAccept(Collections.singletonList(MediaType.APPLICATION_JSON));
    RequestEntity<Void> entity = RequestEntity.method(HttpMethod.GET, uri).headers(headers).build();
    ResponseEntity<Result> resp = restTemplate.exchange(entity, Result.class);
}
```

**请求参数**:

| 名称   | 说明 | 类型   | 描述 | 必须 |
| :----- | ---- | ------ | ---- | ---- |
| apiKey | 密钥 | string | 密钥 | true |

**响应参数**:

| 名称    | 说明              | 类型   | 描述           |
| ------- | ----------------- | ------ | -------------- |
| state   | [状态码](#状态码) | int    | 0成功,其它失败 |
| message | 消息              | string |                |
| value   | token             | string | 安全令牌       |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": "eyJhb9.eyJRmZGY4In0.vRP4-t4yVpaTL-u99JD7-byM1YYdTb_v_Blp27I_4_n-lDqA"
}
```

## 创建用户

**请求方式**:`POST`

**地址**:`https://<server>/channelApi/V3/API/{channel}/createUser`

**请求数据类型**:`application/json`

**响应数据类型**:`application/json`

**接口描述**:<p>供接入方调用,创建用户账号</p>

**请求参数**:

| 名称     | 说明          | 类型   | 描述                                                         | 必须  |
| -------- | ------------- | ------ | ------------------------------------------------------------ | ----- |
| userName | 用户名称      | string | 会员账号的长度建议在**[4,64]**个字符之间,<br/>只可以是字母、数字、下划线的组合,不可<br/>以包含特殊字符. | true  |
| currency | [货币](#币种) | string | 币种类型,默认CNY,若多个玩家属同一代理,<br/>则他们的币种是相同的,币种定义在代理级别. | false |
| agent    | 代理          | string | 会员所属的代理,没有设置代理时可以不<br/>传.长度在4~10个字符之间,由字母、数<br/>字和下划线组成. | false |

**请求示例**:

```javascript
{
 	"userName":"X9528",
    "currency":"CNY",
    "agent":"DT_AGENT"
}
```

**响应参数**:

| 名称    | 说明              | 类型   | 描述           |
| ------- | ----------------- | ------ | -------------- |
| state   | [状态码](#状态码) | int    | 0成功,其它失败 |
| message | 消息              | string |                |
| value   | user              | user   | 用户信息       |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "userName": "X9528",
        "channel": "DT",
        "agent": "DT_AGENT",
        "balance": "0.00",
        "currency": "CNY"
    }
}
```

## 登录游戏

**请求方式**:`GET`

**地址**:`https://<server>/channelApi/V3/API/{channel}/loginWithChannel?userName={userName}`

**描述**:<p>供接入方调用,获得登录游戏的链接,如有直接進厅需求請於登入連結後拼接參數&lobbyId={lobbyId},如有直接进桌需求请于登录链接后拼接参数&tableId={tableId}</p>

**请求参数**:

| 名称     | 说明     | 类型   | 描述                                                         | 必须  |
| -------- | -------- | ------ | ------------------------------------------------------------ | ----- |
| userName | 用户名称 | string | 用户名                                                       | true  |
| language | 语言     | string | 支持中文(默认):zh-cn  <br/>繁体:zh-tw<br/>英文:en-us<br/>韩文:ko-kr<br/>泰文:th-th<br/>越南:vi-vn<br/>巴西-葡萄牙语:pt-br<br/>印尼:hi-in | false |

**响应参数**:

| 名称    | 说明              | 类型   | 描述           |
| ------- | ----------------- | ------ | -------------- |
| state   | [状态码](#状态码) | int    | 0成功,其它失败 |
| message | 消息              | string |                |
| value   | url               | string | 登录游戏链接   |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": "https://***.0***666.com?token=CB0FC676B4***993&language=zh-cn"
}
```

## 登录游戏二(棋牌、电子)

**请求方式**:`GET`

**地址**:`https://<server>/channelApi/V3/API/{channel}/loginWithPlayType?userName={userName}&playType={playType}&gameId={gameId}`

**描述**:<p>供接入方调用,获得棋牌、电子登录游戏的链接</p>

**请求参数**:

| 名称     | 说明     | 类型   | 描述                                                                                                               | 必须    |
| -------- | -------- | ------ |------------------------------------------------------------------------------------------------------------------|-------|
| userName | 用户名称 | string | 用户名                                                                                                              | true  |
| language | 语言     | string | 支持中文(默认):zh-cn  <br/>繁体:zh-tw<br/>英文:en-us<br/>韩文:ko-kr<br/>泰文:th-th<br/>越南:vi-vn<br/>巴西-葡萄牙语:pt-br<br/>印尼:hi-in | false |
| playType | 游戏类型 | int    | 游戏类型, 1:真人 4:棋牌 5:捕鱼                                                                                             | true  |
| gameId   | 游戏ID   | int    | gameId为《Astar游戏列表》中的桌台ID(Room ID),当游戏类型为真人(playType = 1)时,此参数传0或者不传                                         | true  |

**响应参数**:

| 名称    | 说明              | 类型   | 描述           |
| ------- | ----------------- | ------ | -------------- |
| state   | [状态码](#状态码) | int    | 0成功,其它失败 |
| message | 消息              | string |                |
| value   | url               | string | 登录游戏链接   |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": "https://***.0***666.com?token=CB0FC676B4***993&language=zh-cn"
}
```

## 用户登出

**请求方式**:`POST`

**地址**:`https://<server>/channelApi/V3/API/{channel}/logout`

**请求数据类型**:`application/json`

**响应数据类型**:`application/json`

**接口描述**:<p>供接入方调用,用户登出</p>

**请求参数**:

| 名称       | 说明     | 类型      | 描述                   | 必须    |
|----------|--------|---------|----------------------|-------|
| userName | 用户名称   | string  | 用户名                  | true  |
| isKick   | 踢出用户标识 | boolean | 是否为踢出用户下线(提示语：请重新登录) | false |

**请求示例**:

```javascript
{
    "userName":"X9528",
    "isKick":true
}
```

**响应参数**:

| 名称    | 说明              | 类型   | 描述           |
| ------- | ----------------- | ------ | -------------- |
| state   | [状态码](#状态码) | int    | 0成功,其它失败 |
| message | 消息              | string |                |
| value   | value             |        |                |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": null
}
```

## 用户存款

**请求方式**:`POST`

**地址**:`https://<server>/channelApi/V3/API/{channel}/deposit`

**请求数据类型**:`application/json`

**响应数据类型**:`application/json`

**接口描述**:<p>供接入方调用,用户存款</p>

**请求参数**:

| 名称     | 说明     | 类型   | 描述                                                         | 必须 |
| -------- | -------- | ------ | ------------------------------------------------------------ | ---- |
| userName | 用户名称 | string | 用户名                                                       | true |
| amount   | 金额     | string | 金额,大于0 ,且只能保留2位小数,单次存款少于200W人民币(其它货币汇率换算后200W人民币) | true |
| serial   | 订单号   | string | 运营平台创建的唯一订单号,用于唯一性判断,<br/>规则:渠道号+deposit+随机数字或字母,<br/>长度不大于64个字符 | true |

**请求示例**:

```javascript
{
    "userName":"X9528",
    "amount":1000,
    "serial":"DTdeposit231011090333"
}
```

**响应参数**:

| 名称    | 说明              | 类型    | 描述           |
| ------- | ----------------- | ------- | -------------- |
| state   | [状态码](#状态码) | int     | 0成功,其它失败 |
| message | 消息              | string  |                |
| value   | balance           | balance | 账户信息       |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "userName": "X9528",
        "channel": "DT",
        "agent": "DT-AGENT",
        "balance": "1000.00",
        "currency": "CNY"
    }
}
```

## 用户取款

**请求方式**:`POST`

**地址**:`https://<server>/channelApi/V3/API/{channel}/withdraw`

**请求数据类型**:`application/json`

**响应数据类型**:`application/json`

**接口描述**:<p>供接入方调用,用户取款</p>

**请求参数**:

| 名称     | 说明     | 类型   | 描述                                                         | 必须 |
| -------- | -------- | ------ | ------------------------------------------------------------ | ---- |
| userName | 用户名称 | string | 用户名                                                       | true |
| amount   | 金额     | string | 金额,大于0 ,且只能保留2位小数,单次取款少于200W人民币(其它货币汇率换算后200W人民币) | true |
| serial   | 订单号   | string | 运营平台创建的唯一订单号,用于唯一性判断,<br/>规则:渠道号+withdraw+随机数字或字母,<br/>长度不大于64个字符 | true |

**请求示例**:

```javascript
{
    "userName":"X9528",
    "amount":500,
    "serial":"DTwithdraw231011090333"
}
```

**响应参数**:

| 名称    | 说明              | 类型    | 描述           |
| ------- | ----------------- | ------- | -------------- |
| state   | [状态码](#状态码) | int     | 0成功,其它失败 |
| message | 消息              | string  |                |
| value   | balance           | balance | 账户信息       |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "userName": "X9528",
        "channel": "DT",
        "agent": "DT-AGENT",
        "balance": "500.00",
        "currency": "CNY"
    }
}
```

## 获取用户存取款记录

**请求方式**:`GET`

**地址**:`https://<server>/channelApi/V3/API/{channel}/getTrans?userName={userName}`

`&serial={serial}`

**描述**:<p>供接入方调用,获得用户存取款记录</p>

**请求参数**:

| 名称     | 说明     | 类型   | 描述                                                         | 必须 |
| -------- | -------- | ------ | ------------------------------------------------------------ | ---- |
| userName | 用户名称 | string | 用户名                                                       | true |
| serial   | 订单号   | string | 运营平台创建的唯一订单号,用于唯一性判断,<br/>规则:渠道号+deposit+随机数字或字母,<br/>长度不大于64个字符 | true |

**响应参数**:

| 名称    | 说明              | 类型   | 描述           |
| ------- | ----------------- | ------ | -------------- |
| state   | [状态码](#状态码) | int    | 0成功,其它失败 |
| message | 消息              | string |                |
| value   | record            | record | 存取款信息     |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "userName": "DTX9528",
        "serail": "DTdeposit231011101133",
        "beforeBalance": 1000.0,//转账前余额
        "dealBalance": 1000.0,//转账金额
        "afterBalance": 2000.0,//转账后金额
        "changeTime": "2023-10-11 14:11:51",
        "currency": "CNY"
    }
}
```

## 获取渠道存取款记录

**请求方式**:`GET`

**地址**:`https://<server>/channelApi/V3/API/{channel}/getTransList?startTime={startTime}&endTime={endTime}&pageIndex={pageIndex}&pageSize={pageSize}`

**描述**:<p>供接入方调用,获得渠道存取款记录</p>

**请求参数**:

| 名称      | 说明                   | 类型   | 描述                                                         | 必须  |
| --------- | ---------------------- | ------ | ------------------------------------------------------------ | ----- |
| startTime | 开始时间               | string | 开始时间,日期格式yyyy-MM-dd HH:mm:ss                         | true  |
| endTime   | 结束时间               | string | 结束时间,日期格式yyyy-MM-dd HH:mm:ss,<br/>开始时间~结束时间范围在7天内,最早支持查询2个月的数据 | true  |
| pageIndex | 页码,默认1             | int    | 页码                                                         | false |
| pageSize  | 页数,默认200,范围0~200 | int    | 页数                                                         | false |

**响应参数**:

| 名称    | 说明              | 类型         | 描述           |
| ------- | ----------------- | ------------ | -------------- |
| state   | [状态码](#状态码) | int          | 0成功,其它失败 |
| message | 消息              | string       |                |
| value   | transRecords      | transRecords | 存取款记录     |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "total": 2,
        "transRecords": [
            {
                "userName": "DTX9528",
                "agentName": "DT-AGENT",
                "serial": "DTdeposit241011101133",
                "code": "deposite",
                "amount": 200000.0,
                "opTime": "2024-06-10 15:15:08"
            },
            {
                "userName": "DTX9528",
                "agentName": "DT-AGENT",
                "serial": "DTwithdraw231011101133",
                "code": "withdraw",
                "amount": -100.0,
                "opTime": "2024-06-10 15:15:24"
            }
        ],
        "pageIndex": 1,
        "currPageSize": 2,
        "pageSize": 200
    }
}
```

## 获取账户余额

**请求方式**:`GET`

**地址**:`https://<server>/channelApi/V3/API/{channel}/getBalance?userName={userName}`

**描述**:<p>供接入方调用,获取账户余额</p>

**请求参数**:

| 名称     | 说明     | 类型   | 描述     | 必须 |
| -------- | -------- | ------ | -------- | ---- |
| userName | 用户名称 | string | 用户名称 | true |

**响应参数**:

| 名称    | 说明              | 类型    | 描述           |
| ------- | ----------------- | ------- | -------------- |
| state   | [状态码](#状态码) | int     | 0成功,其它失败 |
| message | 消息              | string  |                |
| value   | balance           | balance | 账户信息       |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "userName": "X9528",
        "channel": "DT",
        "agent": "DT-AGENT",
        "balance": "500.00",
        "currency": "CNY",
        "limit": "CA,CB,CC"
    }
}
```

## 批量获取账户余额

**请求方式**:`GET`

**地址**:`https://<server>/channelApi/V3/API/{channel}/getBalanceBatch?userNames={userNames}`

**描述**:<p>供接入方调用,批量获取账户余额</p>

**请求参数**:

| 名称      | 说明               | 类型   | 描述   | 必须 |
| --------- | ------------------ | ------ | ------ | ---- |
| userNames | 用户名称,用","分隔 | string | 用户名 | true |

**响应参数**:

| 名称    | 说明              | 类型    | 描述           |
| ------- | ----------------- | ------- | -------------- |
| state   | [状态码](#状态码) | int     | 0成功,其它失败 |
| message | 消息              | string  |                |
| value   | balance           | balance | 账户信息       |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": [
        {
            "userName": "X9528",
            "balance": 1500.0,
            "limit": "CA,CB,CC"
        }
    ]
}
```

## 获取账户余额列表-账户余额大于设定金额

**请求方式**:`GET`

**地址**:`https://<server>/channelApi/V3/API/{channel}/getBalanceList?amount={amount}`

**描述**:<p>供接入方调用,获取账户余额列表</p>

**请求参数**:

| 名称      | 说明       | 类型   | 描述 | 必须  |
| --------- | ---------- | ------ | ---- | ----- |
| pageIndex | 页码,默认1 | int    | 页码 | false |
| amount    | 额度,默认0 | double | 额度 | false |

**响应参数**:

| 名称    | 说明              | 类型    | 描述           |
| ------- | ----------------- | ------- | -------------- |
| state   | [状态码](#状态码) | int     | 0成功,其它失败 |
| message | 消息              | string  |                |
| value   | balance           | balance | 账户信息       |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "total": 1577,
        "records": [
            {
                "userName": "X9528",
                "amount": 9997,
                "limit": "CA,CB,CC"
            }
        ],
        "pageIndex": 1,
        "currPageSize": 1000,
        "pageSize": 1000
    }
}
```

## 获取用户状态

**请求方式**:`GET`

**地址**:`https://<server>/channelApi/V3/API/{channel}/getUserAvailable?userName={userName}`

**描述**:<p>供接入方调用,获取用户状态</p>

**请求参数**:

| 名称     | 说明     | 类型   | 描述   | 必须 |
| -------- | -------- | ------ | ------ | ---- |
| userName | 用户名称 | string | 用户名 | true |

**响应参数**:

| 名称    | 说明              | 类型      | 描述                         |
| ------- | ----------------- | --------- | ---------------------------- |
| state   | [状态码](#状态码) | int       | 0成功,其它失败               |
| message | 消息              | string    |                              |
| value   | available         | available | 0:正常;1:禁止下注 2:停用账号 |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "userName": "X9528",
        "available": 0
    }
}
```

## 设置用户状态

**请求方式**:`POST`

**地址**:`https://<server>/channelApi/V3/API/{channel}/setUserAvailable`

**请求数据类型**:`application/json`

**响应数据类型**:`application/json`

**接口描述**:<p>供接入方调用,设置用户状态</p>

**请求参数**:

| 名称      | 说明   | 类型   | 描述                         | 必须 |
| --------- | ------ | ------ | ---------------------------- | ---- |
| userName  | 用户名 | string | 用户名                       | true |
| available | 状态   | int    | 0:正常;1:禁止下注 2:停用账号 | true |

**请求示例**:

```javascript
{
    "userName":"X9528",
    "available":0
}
```

**响应参数**:

| 名称    | 说明              | 类型      | 描述                                    |
| ------- | ----------------- | --------- | --------------------------------------- |
| state   | [状态码](#状态码) | int       | 0成功,其它失败                          |
| message | 消息              | string    |                                         |
| value   | available         | available | available: 0:正常;1:禁止下注 2:停用账号 |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "userName": "X9528",
        "available": 0
    }
}
```

## 设置限额

**请求方式**:`POST`

**地址**:`https://<server>/channelApi/V3/API/{channel}/setUserLimit`

**请求数据类型**:`application/json`

**响应数据类型**:`application/json`

**接口描述**:<p>供接入方调用,设置用户限额</p>

**请求参数**:

| 名称       | 说明      | 类型      | 描述                                                                                                   | 必须    |
|----------|---------|---------|------------------------------------------------------------------------------------------------------|-------|
| userName | 用户名     | string  | 用户名(如果isAgent为true,则为代理的用户名，如果isAgent为false或该参数不传,则为会员的用户名)                                          | true  |
| limit    | 限额      | string  | CA:10-1000,CB: 10-10000,CC: 10-30000,CD:10-50000,CE: 10-100000,CF: 10-150000,CG: 10-200000,参数使用","分隔 | true  |
| isAgent  | 是否代理账号 | boolean | 是否为代理账号，true时修改代理账号为userName的限额，false或不传时修改玩家账号为userName的限额, 默认为false                                | false |

**请求示例**:

1.修改玩家限额
```javascript
{
    "userName":"X9528",
    "limit":"CA,CB,CC"
}
```
2.修改代理限额
```javascript
{
    "userName":"X9528",
    "limit":"CA,CB,CC",
    "isAgent":true
}
```

**响应参数**:

| 名称    | 说明              | 类型   | 描述           |
| ------- | ----------------- | ------ | -------------- |
| state   | [状态码](#状态码) | int    | 0成功,其它失败 |
| message | 消息              | string |                |
| value   | quota             | string | 限额信息       |

**响应示例**:

```javascript
{
    "state": 0,
        "message": "成功",
        "value": [
        {
            "id": 31892,
            "parentid": 18354,
            "parentclass": "com.fontana.wraper.UserWraper",
            "name": "CA",
            "type": 0
        }
    ]
}
```
## 创建代理

**请求方式**:`POST`

**地址**:`https://<server>/channelApi/V3/API/{channel}/createAgent`

**请求数据类型**:`application/json`

**响应数据类型**:`application/json`

**接口描述**:<p>供接入方调用,创建代理账号</p>

**请求参数**:

| 名称        | 说明          | 类型   | 描述                                                                                                     | 必须    |
|-----------| ------------- | ------ |--------------------------------------------------------------------------------------------------------|-------|
| agentName | 用户名称      | string | 会员账号的长度建议在**[4,64]**个字符之间,<br/>只可以是字母、数字、下划线的组合,不可<br/>以包含特殊字符.             | true  |
| currency  | [货币](#币种) | string | 币种类型,默认CNY,若多个玩家属同一代理,<br/>则他们的币种是相同的,币种定义在代理级别.                                  | false |
| limit     | 代理          | string | CA:10-1000,CB: 10-10000,CC: 10-30000,CD:10-50000,CE: 10-100000,CF: 10-150000,CG: 10-200000,参数使用","分隔 ,默认渠道限额 | false |

**请求示例**:

```javascript
{
    "agentName":"X9528",
    "currency":"CNY",
    "limit":"CA,CB,CC"
}
```

**响应参数**:

| 名称    | 说明              | 类型   | 描述           |
| ------- | ----------------- | ------ | -------------- |
| state   | [状态码](#状态码) | int    | 0成功,其它失败 |
| message | 消息              | string |                |
| value   | user              | user   | 用户信息       |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "agentName": "X9528",
        "channel": "DT",
        "balance": "0.00",
        "limit": "CA,CB,CC",
        "currency": "CNY"
    }
}
```

## 获取用户在线状态

**请求方式**:`GET`

**地址**:`https://<server>/channelApi/V3/API/{channel}/getUserOnlineState?userName={userName}`

**描述**:<p>供接入方调用,获取用户在线状态</p>

**请求参数**:

| 名称     | 说明     | 类型   | 描述   | 必须 |
| -------- | -------- | ------ | ------ | ---- |
| userName | 用户名称 | string | 用户名 | true |

**响应参数**:

| 名称    | 说明              | 类型   | 描述            |
| ------- | ----------------- | ------ | --------------- |
| state   | [状态码](#状态码) | int    | 0成功,其它失败  |
| message | 消息              | string |                 |
| value   | online            | int    | 0:不在线;1:在线 |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "userName": "X9528",
        "online": 0
    }
}
```

## 获取渠道在线用户

**请求方式**:`GET`

**地址**:`https://<server>/channelApi/V3/API/{channel}/getChannelOnlineList`

**描述**:<p>供接入方调用,获取渠道在线用户</p>

**请求参数**:

**响应参数**:

| 名称    | 说明              | 类型       | 描述                                                         |
| ------- | ----------------- | ---------- | ------------------------------------------------------------ |
| state   | [状态码](#状态码) | int        | 0成功,其它失败                                               |
| message | 消息              | string     |                                                              |
| value   | onlineUser        | onlineUser | location,0-大厅,1-百家乐,2-龙虎,3-轮盘,4-骰宝,5-牛牛,6-德州,7-扎金花 |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": [
        {
            "userName": "b6945c00018aead2",
            "location": 1
        }
    ]
}
```

## 获取用户注单链接

**请求方式**:`GET`

**地址**:`https://<server>/channelApi/V3/API/{channel}/getBetInfoDetailLink?betId={betId}&lang={lang}`

**描述**:<p>供接入方调用,获取用户注单详情链接</p>

**请求参数**:

| 名称  | 说明   | 类型   | 描述                                                 | 必须  |
| ----- | ------ | ------ | ---------------------------------------------------- | ----- |
| betId | 注单ID | long   | 注单ID                                               | true  |
| lang  | 语言   | String | 支持中文(默认):zh-cn  <br/>繁体:zh-tw<br/>英文:en-us | false |

**响应参数**:

| 名称    | 说明              | 类型   | 描述           |
| ------- | ----------------- | ------ | -------------- |
| state   | [状态码](#状态码) | int    | 0成功,其它失败 |
| message | 消息              | string |                |
| value   | link              | string | 注单详情url    |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": "https://***.0***666.com/history_detail/index.html?token=8CuyZd2N6U1StTM5Ocy3&language=zh-cn&betId=13213&channel=LP"
}
```

## 获取用户区块链游戏注单详情链接

**请求方式**:`GET`

**地址**:`https://<server>/channelApi/V3/API/{channel}/getHashBetDetailUrl?recordId={recordId}&lang={lang}`

**描述**:<p>供接入方调用,获取用户区块链游戏注单详情链接</p>

**请求参数**:

| 名称     | 说明   | 类型   | 描述                                                         | 必须  |
| -------- | ------ | ------ | ------------------------------------------------------------ | ----- |
| recordId | 注单ID | long   | 注单ID                                                       | true  |
| lang     | 语言   | String | 支持中文(默认):zh-cn  <br/>繁体:zh-tw<br/>英文:en-us<br/>韩文:ko-kr<br/>泰文:th-th<br/>越南:vi-vn<br/> | false |

**响应参数**:

| 名称    | 说明              | 类型   | 描述           |
| ------- | ----------------- | ------ | -------------- |
| state   | [状态码](#状态码) | int    | 0成功,其它失败 |
| message | 消息              | string |                |
| value   | link              | string | 注单详情url    |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": "value": "https://<server>/bet_info.html?merchant_id=*&desk_id=*&game_id=*&order_id=*&lang=zh-	hans&token=eyJhbGci**"
}
```

## 获取用户棋牌游戏注单详情链接

**请求方式**:`GET`

**地址**:`https://<server>/channelApi/V3/API/{channel}/getBetDetailUrl?recordId={recordId}&lang={lang}`

**描述**:<p>供接入方调用,获取用户棋牌游戏注单详情链接</p>

**请求参数**:

| 名称     | 说明   | 类型   | 描述                                                         | 必须  |
| -------- | ------ | ------ | ------------------------------------------------------------ | ----- |
| recordId | 注单ID | long   | 注单ID                                                       | true  |
| lang     | 语言   | String | 支持中文(默认):zh-cn  <br/>繁体:zh-tw<br/>英文:en-us<br/>韩文:ko-kr<br/>泰文:th-th<br/>越南:vi-vn<br/> | false |

**响应参数**:

| 名称    | 说明              | 类型   | 描述           |
| ------- | ----------------- | ------ | -------------- |
| state   | [状态码](#状态码) | int    | 0成功,其它失败 |
| message | 消息              | string |                |
| value   | link              | string | 注单详情url    |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": "value": "https://<server>/ChannelApi/API/VG/GetGameResultBox?uid=28*****8&gametype=1&datatype=1"
}
```

## 获取用户注单记录汇总

**请求方式**:`GET`

**地址**:`https://<server>/channelApi/V3/API/{channel}/getRecordTotalByTime?startTime={startTime}&endTime={endTime}&agentName={agentName}`

**描述**:<p>供接入方调用,按时间段获取注单数据汇总[getRecordTotalByTime].本接口10s只允许调用2次.</p>

**请求参数**:

| 名称      | 说明                                                         | 类型   | 描述     | 必须  |
| --------- | ------------------------------------------------------------ | ------ | -------- | ----- |
| startTime | 开始时间,日期格式yyyy-MM-dd HH:mm:ss                         | string | 开始时间 | true  |
| endTime   | 结束时间,日期格式yyyy-MM-dd HH:mm:ss<br/>开始时间~结束时间范围在31天内 | string | 结束时间 | true  |
| agentName | 代理名称                                                     | string | 代理名称 | false |

**响应参数**:

| 名称    | 说明              | 类型   | 描述           |
| ------- | ----------------- | ------ | -------------- |
| state   | [状态码](#状态码) | int    | 0成功,其它失败 |
| message | 消息              | string |                |
| value   | total             | total  | 注单记录汇总   |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "totalOrder": 187,//总比数
        "totalBetAmount": 266208.0,//总投注金额
        "totalCommAmount": 219764.1,//总洗码金额
        "totalResultAmount": -38914.9//总输赢金额
    }
}
```

## 获取用户注单记录(推荐)

**请求方式**:`GET`

**地址**:`https://<server>/channelApi/V3/API/{channel}/getRecordByCondition?startTime={startTime}&endTime={endTime}&agentName={agentName}&correctTime={correctTime}&pageIndex={pageIndex}&pageSize={pageSize}&version={version}`

**描述**:<p>供接入方调用,按时间段获取注单[getRecordByCondition],此时间段内的所有注单会以分页的方式返回,首次页数从1开始,每次都会返回此时间段的总条数.本接口10s只允许调用10次,每次最大返回200条数据,correctTime为拉取到的最后一条数据的结束时间,同一时段内每次拉取注单时需更新correctTime.</p>

**请求参数**:

| 名称        | 说明                                                         | 类型   | 描述     | 必须  |
| ----------- | ------------------------------------------------------------ | ------ | -------- | ----- |
| startTime   | 开始时间,日期格式yyyy-MM-dd HH:mm:ss<br>支持最近一个月的数据,空格需要转义为%20 | string | 开始时间 | true  |
| endTime     | 结束时间,日期格式yyyy-MM-dd HH:mm:ss<br/>开始时间~结束时间范围在24小时内,空格需要转义为%20 | string | 结束时间 | true  |
| agentName   | 代理名称                                                     | string | 代理名称 | false |
| correctTime | 结算时间,日期格式yyyy-MM-dd HH:mm:ss,拉取注单数据<br/>最后一条数据的结算时间,第一次拉取数据,<br>值设置为开始时间,空格需要转义为%20 | string | 结算时间 | true  |
| pageIndex   | 页码,默认1                                                   | int    | 页码     | false |
| pageSize    | 页数,默认100,范围0~200                                       | int    | 页数     | false |
| version     | 版本标识，默认值3.0：真人游戏注单，3.1：真人、直播、区块链、棋牌、捕鱼游戏注单 | string | 版本标识 | false |

**响应参数**:

| 名称    | 说明                          | 类型         | 描述           |
| ------- | ----------------------------- | ------------ | -------------- |
| state   | [状态码](#状态码)             | int          | 0成功,其它失败 |
| message | 消息                          | string       |                |
| value   | [game records](#注单字段详解) | game records | 注单记录       |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "gameRecords": [
            {
                "id": 415,
                "userName": "DT6501050d0dbe5769a97cad88",
                "channel": "DT",
                "agent": "621829689c133400019eb38d",
                "createTime": "2023-09-13 08:42:27",
                "gameType": 1,
                "tableId": "41",
                "roundId": "60749966",
                "betAmount": 10.0,
                "validBetAmount": 10.0,
                "betPoint": "PLAYER:10.00@10.00@10.00#",
                "odds": null,
                "money": 10.0,
                "serviceMoney": null,
                "beginTime": "2023-09-13 08:41:52",
                "endTime": "2023-09-13 08:42:47",
                "groupFor": "2023-09-12",
                "isBanker": 0,
                "gameInfo": "12-3-0;6-3-1;7-2-2;4-2-3;0-0-4;2-3-5",
                "gameResult": "PLAYER",
                "beforeBalance": null,
                "status": "A",
                "info1": null,
                "jp": 0,
                "enterType": 0,
                "shoeNum": 18,
                "gamblingNum": 19,
                "ip": "18.139.29.99",
                "currency": "CNY",
                "recordId": 1527397,//version 3.1
                "playType": 1 //version 3.1
            }
        ],
        "lastRecordId": 5962,
        "total": 1,
        "pageIndex": 1,
        "currPageSize": 1,
        "pageSize": 200
    }
}
```

## 获取用户注单记录二

**请求方式**:`GET`

**地址**:`https://<server>/channelApi/V3/API/{channel}/getRecordByTime?startTime={startTime}&endTime={endTime}&pageIndex={pageIndex}&pageSize={pageSize}&version={version}`

**描述**:<p>供接入方调用,按时间段获取注单[getRecordByTime],此时间段内的所有注单会以分页的方式返回,首次页数从1开始,每次都会返回此时间段的总条数.本接口10s只允许调用10次,每次最大返回200条数据.</p>

**请求参数**:

| 名称      | 说明                                                         | 类型   | 描述     | 必须  |
| --------- | ------------------------------------------------------------ | ------ | -------- | ----- |
| startTime | 开始时间,日期格式yyyy-MM-dd HH:mm:ss<br>支持最近一个月的数据,空格需要转义为%20 | string | 开始时间 | true  |
| endTime   | 结束时间,日期格式yyyy-MM-dd HH:mm:ss<br/>开始时间~结束时间范围在24小时内,空格需要转义为%20 | string | 结束时间 | true  |
| agentName | 代理名称                                                     | string | 代理名称 | false |
| pageIndex | 页码                                                         | int    | 页码     | true  |
| pageSize  | 页数,默认100,范围0~200                                       | int    | 页数     | false |
| version   | 版本标识，默认值3.0：真人游戏注单，3.1：真人、直播、区块链、棋牌、捕鱼游戏注单 | string | 版本标识 | false |

**响应参数**:

| 名称    | 说明                          | 类型         | 描述           |
| ------- | ----------------------------- | ------------ | -------------- |
| state   | [状态码](#状态码)             | int          | 0成功,其它失败 |
| message | 消息                          | string       |                |
| value   | [game records](#注单字段详解) | game records | 注单记录       |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "gameRecords": [
            {
                "id": 415,
                "userName": "DT6501050d0dbe5769a97cad88",
                "channel": "DT",
                "agent": "621829689c133400019eb38d",
                "createTime": "2023-09-13 08:42:27",
                "gameType": 1,
                "tableId": "41",
                "roundId": "60749966",
                "betAmount": 10.0,
                "validBetAmount": 10.0,
                "betPoint": "PLAYER:10.00@10.00@10.00#",
                "odds": null,
                "money": 10.0,
                "serviceMoney": null,
                "beginTime": "2023-09-13 08:41:52",
                "endTime": "2023-09-13 08:42:47",
                "groupFor": "2023-09-12",
                "isBanker": 0,
                "gameInfo": "12-3-0;6-3-1;7-2-2;4-2-3;0-0-4;2-3-5",
                "gameResult": "PLAYER",
                "beforeBalance": null,
                "status": "A",
                "info1": null,
                "jp": 0,
                "enterType": 0,
                "shoeNum": 18,
                "gamblingNum": 19,
                "ip": "18.139.29.99",
                "currency": "CNY",
                "recordId": 1527397,//version 3.1
                "playType": 1 //version 3.1
            }
        ],
        "lastRecordId": 5962,
        "total": 1,
        "pageIndex": 1,
        "currPageSize": 1,
        "pageSize": 200
    }
}
```

## 获取用户注单记录三(真人游戏、直播游戏、区块链游戏、棋牌捕鱼游戏)

**请求方式**:`GET`

**地址**:`https://<server>/channelApi/V3/API/{channel}/getRecordByMaxId?maxRecordId={maxRecordId}&type={type}&pageIndex={pageIndex}&pageSize={pageSize}`

**描述**:<p>供接入方调用,按最大ID获取注单[getRecordByMaxId],所有注单会以分页的方式返回,首次页数从1开始,每次都会返回此时间段的总条数.本接口10s只允许调用10次,每次最大返回200条数据.maxRecordId为拉取到的最后一条数据的recordId,同一时段内每次拉取注单时需更新maxRecordId.</p>

**请求参数**:

| 名称        | 说明                                                         | 类型 | 描述   | 必须  |
| ----------- | ------------------------------------------------------------ | ---- | ------ | ----- |
| maxRecordId | 记录ID                                                       | long | 记录ID | true  |
| type        | 类型:默认0,范围0~5,0-全部、1-真人、2-直播、3-区块链、4-棋牌、5-捕鱼 | int  | 类型   | false |
| pageIndex   | 页码                                                         | int  | 页码   | true  |
| pageSize    | 页数,默认100,范围0~200                                       | int  | 页数   | false |

**响应参数**:

| 名称    | 说明                          | 类型         | 描述           |
| ------- | ----------------------------- | ------------ | -------------- |
| state   | [状态码](#状态码)             | int          | 0成功,其它失败 |
| message | 消息                          | string       |                |
| value   | [game records](#注单字段详解) | game records | 注单记录       |

**响应示例**:

```javascript
{
    "state": 0,
    "message": "成功",
    "value": {
        "gameRecords": [
            {
                "recordId": 1568487,
                "id": 1714485061983433,
                "userName": "SWu1LxXc",
                "channel": "SW",
                "agent": "SW-AGENT",
                "createTime": "2024-04-30 21:50:34",
                "gameType": 6333,
                "tableId": "10246",
                "roundId": "180260",
                "betAmount": 10.0,
                "validBetAmount": 10.0,
                "betPoint": "骰宝币安链",
                "money": 120.0,
                "beginTime": "2024-04-30 21:51:01",
                "endTime": "2024-04-30 21:51:01",
                "groupFor": "2024-04-30",
                "status": "A",
                "shoeNum": 0,
                "gamblingNum": 0,
                "currency": "CNY",
                "playType": 1 
            }
        ],
        "lastRecordId": 5962,
        "total": 1,
        "pageIndex": 1,
        "currPageSize": 1,
        "pageSize": 200
    }
}
```

## 注单字段详解

| 名称           | 类型     | 描述                                                                                                                                                                                |
| -------------- | -------- |-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| id             | int      | 注单id                                                                                                                                                                              |
| status         | string   | 单状态,A: 已派彩 B:未结算(状态异常) C:注单取消                                                                                                                                                         |
| userName       | string   | 用户名称                                                                                                                                                                              |
| channel        | string   | 渠道号                                                                                                                                                                               |
| agent          | string   | 代理号                                                                                                                                                                               |
| createTime     | datetime | 创建时间为北京时间(yyyy-MM-dd HH:mm:ss)                                                                                                                                                    |
| groupFor       | date     | 更数,例如2024-05-31 12:00:00 ~06-01 12:00:00,更数是2024-05-31                                                                                                                            |
| gameType       | int      | 【真人视讯游戏类型】百家乐:1、 龙虎:2、 轮盘:3、 骰宝:4、 牛牛:5、炸金花:12<br/>【区块链游戏类型】百家乐:1000 、龙虎:1001、21点:1002、数字哈希:1003  、双尾哈希:1004、<br/>炸金花:1005、牛牛:1006、幸运德州:1007、轮盘:1008、骰宝:1009、极限跳伞:2000、极限跳伞2:2001 |
| tableId        | string   | 桌号                                                                                                                                                                                |
| roundId        | string   | 局id                                                                                                                                                                               |
| betAmount      | double   | 投注额,单位为人民币                                                                                                                                                                        |
| validBetAmount | double   | 有效投注额,单位为人民币                                                                                                                                                                      |
| betPoint       | string   | 下注点,建议预留2000字节                                                                                                                                                                    |
| odds           | double   | 赔率(翻倍数)                                                                                                                                                                           |
| money          | double   | 输赢金额                                                                                                                                                                              |
| currency       | string   | 币种单位                                                                                                                                                                              |
| serviceMoney   | double   | 服务费(抽水)                                                                                                                                                                           |
| beginTime      | string   | 游戏开始时间为北京时间(yyyy-MM-dd HH:mm:ss)                                                                                                                                                  |
| endTime        | string   | 游戏结束时间为北京时间(yyyy-MM-dd HH:mm:ss)                                                                                                                                                  |
| isBanker       | int      | 废弃字段，庄闲 1表示庄 0表示闲                                                                                                                                                                 |
| gameInfo       | string   | 发牌情况,建议预留1000字节                                                                                                                                                                   |
| gameResult     | string   | 游戏开奖结果                                                                                                                                                                            |
| jp             | int      | 下注方式: 0表示非免佣,1表示免佣,只针对百家乐(庄)注点生效                                                                                                                                                  |
| info1          | string   | 额外字段1,默认为空,值根据根据游戏而定,建议预留1000字节                                                                                                                                                   |
| shoeNum        | int      | 靴数                                                                                                                                                                                |
| gamblingNum    | int      | 局数                                                                                                                                                                                |
| enterType      | int      | 下注方式:1大厅 2换桌列表 3多台 4桌台内（进桌）                                                                                                                                                       |
| ip             | string   | 玩家投注时客户端ip                                                                                                                                                                        |
| recordId       | long     | 第三方游戏预留字段，记录id（V3.1）                                                                                                                                                              |
| playType       | int      | 游戏类型,1:真人 2:直播 3:区块链 4:棋牌 5:捕鱼（V3.1）                                                                                                                                              |

## **百家乐**

**gameInfo解析说明**

百家乐的gameInfo中记录了发牌信息,每张牌之间用“;”分隔,先发闲家牌,再发庄家牌.示例如下:

```
3-3-0;6-2-1;5-2-2;11-1-3;0-0-4;0-0-5
```

**字段解析说明**

| 示例:11-1-3 | 解析                  | 说明                                                         |
| ----------- | --------------------- | ------------------------------------------------------------ |
| 11          | J                     | 牌的点数(1,2,3,4,5,6,7,8,9,10,11,12,13),0代表无效,不存在     |
| 1           | 黑桃                  | 牌的花色(1黑桃SPADE,2红心 HEART,3梅花CLUB,<br/>4方块DIAMOND),0代表无效,不存在 |
| 3           | 庄家第二张牌(banker2) | 用来区分庄、闲牌,闲家第一张牌是0, 庄家第一张牌是1,<br/> 闲家第二张牌是2, 庄家第二张牌是3, 闲家第三张牌是4,<br/> 庄家第三张牌是5 |

**gameResult解析说明**

百家乐 gameResult中记录了胜出的注点,示例如下:

```
BANKER
```

**字段解析说明**

| 名称   | 示例   | 说明                                   |
| ------ | ------ | -------------------------------------- |
| BANKER | BANKER | 庄闲和(BANKER: 庄,PLAYER: 闲,TILE: 和) |

**betPoint解析说明**

百家乐中记录了用户的投注及获奖信息,示例如下:

```
PLAYER:3000.00@0.00@0.00#
```

对应示例解析说明:

注点名:下注金额@输赢额@洗码量#,多注点使用"#"分割

| 名称   | 示例   | 说明                                                         |
| ------ | ------ | ------------------------------------------------------------ |
| BANKER | BANKER | 庄闲和(BANKER: 庄,PLAYER: 闲,TILE: 和)                       |
| PP     | PP     | 单双对子(BP: 庄对,PP: 闲对,BO: 庄单,BE: 庄双,PO: 闲单,PE: 闲双,SS: super six,LS: 幸运六) |
| SMALL  | SMALL  | 大小(BIG: 大,SMALL: 小)                                      |
| BN     | BN     | 庄例牌                                                       |
| PN     | PN     | 闲例牌                                                       |
| AP     | AP     | 任意对子                                                     |
| PFP    | PFP    | 完美对子                                                     |
| BDB    | BDB    | 庄龙宝                                                       |
| PDB    | PDB    | 闲龙宝                                                       |



## **龙虎**

**gameInfo解析说明**

龙虎的gameInfo中记录了发牌信息,字段用“;”分隔,示例如下:

```
10-2-0;7-2-1
```

**字段解析说明**

| 示例:10-2-0 | 解析         | 说明                                                        |
| ----------- | ------------ | ----------------------------------------------------------- |
| 10          | 10           | 牌的点数(1,2,3,4,5,6,7,8,9,10,11,12,13)                     |
| 2           | 红心         | 牌的花色(1黑桃SPADE,2红心 HEART,3梅花CLUB,<br>4方块DIAMOND) |
| 0           | 第一张牌(虎) | 牌的位置(虎0；龙1)                                          |

**gameResult解析说明**

龙虎gameResult中记录了胜出的注点,示例如下:

```
BANKER
```

**字段解析说明**

| 名称   | 示例   | 说明                                   |
| ------ | ------ | -------------------------------------- |
| BANKER | BANKER | 龙虎和(BANKER: 龙,PLAYER: 虎,TILE: 和) |

**betPoint解析说明**

龙虎betPoint 中记录了用户的下注金额和输赢金额,示例如下:

```
PLAYER:3000.00@0.00@0.00#
```

对应示例解析说明:

注点名:下注金额@输赢额@洗码量#,多注点使用"#"分割

## **牛牛**

**gameInfo解析说明**

牛牛的gameInfo中记录了发牌信息,字段用“;”分隔,示例如下:

```
13-1-0;9-1-1;8-4-2;8-3-3;2-2-4;4-4-5;10-2-6;6-3-7;12-4-8;9-4-9;2-1-10;10-3-11;4-1-12;3-4-13;8-2-14;2-4-15;6-4-16;5-3-17;10-1-18;7-3-19;7-1-20
```

**字段解析说明**

| 示例:10-2-0 | 解析 | 说明                                                    |
| ----------- | ---- | ------------------------------------------------------- |
| 10          | 10   | 牌的点数(1,2,3,4,5,6,7,8,9,10,11,12,13)                 |
| 2           | 红心 | 牌的花色(1黑桃SPADE,2红心 HEART,3梅花CLUB,4方块DIAMOND) |
| 0           | 头牌 | 牌的位置(头牌0,庄,1-5,闲1,6-10,闲2,11-15,闲3,16-20)     |

**gameResult解析说明**

牛牛gameResult中记录了胜出的注点,示例如下:

```
[{\"fullNiu\":false,\"hasNiu\":true,\"niuIndex\":[1,2,4],\"point\":1,\"ratio\":0.0},{\"fullNiu\":false,\"hasNiu\":false,\"niuIndex\":[],\"point\":0,\"ratio\":-1.0,\"win\":false},{\"fullNiu\":false,\"hasNiu\":true,\"niuIndex\":[0,3,4],\"point\":7,\"ratio\":1.9,\"win\":true},{\"fullNiu\":false,\"hasNiu\":true,\"niuIndex\":[0,3,4],\"point\":5,\"ratio\":0.95,\"win\":true}]
```

**字段解析说明**

| 名称     | 示例  | 说明                              |
| -------- | ----- | --------------------------------- |
| fullNiu  | false | 是否为全牛                        |
| hasNiu   | true  | 是否有牛                          |
| point    | 1     | 点数                              |
| win      | true  | true赢 false 输                   |
| niuIndex | 1,2,4 | 某一家其5张牌的下标,这3张牌组成牛 |
| ratio    | 1.9   | 赔率,正数为赢,负数为输            |

**betPoint解析说明**

牛牛betPoint 中记录了用户的下注金额和输赢金额,示例如下:

```
PLAYER1:1000.00@-1000.00@1000.00
```

对应示例解析说明:

注点名:下注金额@输赢额@洗码量#,多注点使用"#"分割

**字段解析说明**

| 名称              | 示例              | 说明        |
| ----------------- | ----------------- | ----------- |
| PLAYER1           | PLAYER1           | 闲1平倍     |
| PLAYER2           | PLAYER2           | 闲2平倍     |
| PLAYER3           | PLAYER3           | 闲3平倍     |
| FAN_PLAYER1       | FAN_PLAYER1       | 闲1翻倍     |
| FAN_PLAYER2       | FAN_PLAYER2       | 闲2翻倍     |
| FAN_PLAYER3       | FAN_PLAYER3       | 闲3翻倍     |
| YAJIN_FAN_PLAYER1 | YAJIN_FAN_PLAYER1 | 闲1翻倍押金 |
| YAJIN_FAN_PLAYER2 | YAJIN_FAN_PLAYER2 | 闲2翻倍押金 |
| YAJIN_FAN_PLAYER3 | YAJIN_FAN_PLAYER3 | 闲3翻倍押金 |

## **轮盘**

**gameInfo解析说明**

轮盘的gameInfo中记录了发牌信息,字段用“;”分隔,示例如下:

```
1
```

**字段解析说明**

| 示例:1 | 解析        | 说明            |
| ------ | ----------- | --------------- |
| 1      | 开彩的点数1 | 开彩的点数0到36 |

**gameResult解析说明**

轮盘gameResult中记录了胜出的注点,示例如下:

```
1
```

**字段解析说明**

| 名称       | 示例 | 说明      |
| ---------- | ---- | --------- |
| gameResult | 1    | 开彩点数1 |

**betPoint解析说明**

轮盘betPoint 中记录了用户的下注金额和输赢金额,示例如下:

```
RoSm:100.00@100.00@100.00#RoDu12:100.00@1700.00@100.00#RoOdd:100.00@100.00@100.00#Ro12s1:100.00@200.00@100.00#Ro1245:100.00@800.00@100.00#RoDu14:100.00@1700.00@100.00#RoSi01:100.00@3500.00@100.00#RoRed:100.00@100.00@100.00#
```

对应示例解析说明:

注点名:下注金额@输赢额@洗码量#,多注点使用"#"分割

**注点明细:**

| 名称     | 说明                                                         |
| -------- | ------------------------------------------------------------ |
| 单双     | RoOdd:单,RoEven:双                                           |
| 黑红     | RoBak: 黑,RoRed:红                                           |
| 大小     | RoBig:大,RoSm:小                                             |
| 下注一打 | Ro12s1:第一打,Ro12s2:第二打,Ro12s3:第三打                    |
| 列注     | RoRow1:第一列,RoRow2:第二列,RoRow3:第三列                    |
| 线注     | RoCol1,RoCol2, RoCol3,RoCol4,RoCol5,RoCol6,RoCol7,<br>RoCol8,RoCol9,RoCol0,RoCola |
| 直接注   | RoSi01,RoSi02,RoSi03,RoSi04,RoSi05,RoSi06,RoSi07, <br/>RoSi08,RoSi09,RoSi10,RoSi11,RoSi12,RoSi13,RoSi14, <br/>RoSi15,RoSi16,RoSi17,RoSi18,RoSi19,RoSi20,RoSi21,<br/>RoSi22,RoSi23,RoSi24,RoSi25,RoSi26,RoSi27,RoSi28, <br/>RoSi29,RoSi30,RoSi31,RoSi32,RoSi33,RoSi34,RoSi35, <br/>RoSi36,RoSi88 |
| 分注     | RoDu12,RoDu23,RoDu36,RoDu14,RoDu25,RoDu45,RoDu56,<br/> RoDu47,RoDu58,RoDu69,RoDu78,RoDu89,RoDu70,RoDu8a, <br/>RoDu9b,RoDu0a,RoDuab,RoDu0c,RoDuad,RoDube,RoDucd,<br/> RoDude,RoDucf,RoDudg,RoDueh,RoDufg,RoDugh,RoDufi, <br/>RoDugj,RoDuhk,RoDuij,RoDujk,RoDuil,RoDujm,RoDukn, <br/>RoDulm,RoDumn,RoDulo,RoDump,RoDunq,RoDuop,RoDupq,<br/> RoDuor,RoDups,RoDuqt,RoDurs,RoDust,RoDuru,RoDusv,RoDutw,<br/> RoDuuv,RoDuvy,RoDuwz,RoDuxy,RoDuyz,RoDu_1,RoDu_2,<br/> RoDu_3,RoDuux,RoDuvw |
| 三数     | RoT_12,RoT_23                                                |
| 街注     | RoT123,RoT456,RoT789,RoT0ab,RoTcde,RoTfgh,RoTijk,RoTlmn,<br/> RoTopq,RoTrst,RoTuvw,RoTxyz |
| 四个号码 | Ro_123                                                       |
| 角注     | Ro1245,Ro2356,Ro5689,Ro4578,Ro89ab,Ro780a,Ro0acd,<br/> Roabde,Rocdfg,Rodegh,Rofgij,Roghjk,Roijlm,Rojkmn, <br/>Romnpq,Rooprs,Ropqst,Rorsuv,Rostvw,Rouvxy,Rovwyz ,Rolmop |

**对应文字描述**

RoEven = 双;RoOdd = 单;Ro12s1 = 第一打;Ro12s2 = 第二打;Ro12s3 = 第三打;RoRow1 = 第一列;RoRow2 = 第二列;RoRow3 = 第三列;RoSm = 小;RoBig = 大;RoSm1 = 小  1-18 ;RoBig1 = 大  19-36;RoBak = 黑;RoRed = 红;RedBak = 红 / 黑;BigSm = 大 / 小;TaxiList = 打 / 列;OddEven = 单 / 双;Direct_Bet = 直接注;Marks_Bet = 分注;Street_Bet = 街注;Three_Several = 三数;Corner_Bet = 角注;Four_Bet = 四个号码;Line_Bet = 线注;Make_Bet = 列注;Bet_Dozen = 下注一打;RoSi88 = 直注0;RoSi01 = 直注1;RoSi02 = 直注2;RoSi03 = 直注3;RoSi04 = 直注4;RoSi05 = 直注5;RoSi06 = 直注6;RoSi07 = 直注7;RoSi08 = 直注8;RoSi09 = 直注9;RoSi10 = 直注10;RoSi11 = 直注11;RoSi12 = 直注12;RoSi13 = 直注13;RoSi14 = 直注14;RoSi15 = 直注15;RoSi16 = 直注16;RoSi17 = 直注17;RoSi18 = 直注18;RoSi19 = 直注19;RoSi20 = 直注20;RoSi21 = 直注21;RoSi22 = 直注22;RoSi23 = 直注23;RoSi24 = 直注24;RoSi25 = 直注25;RoSi26 = 直注26;RoSi27 = 直注27;RoSi28 = 直注28;RoSi29 = 直注29;RoSi30 = 直注30;RoSi31 = 直注31;RoSi32 = 直注32;RoSi33 = 直注33;RoSi34 = 直注34;RoSi35 = 直注35;RoSi36 = 直注36;RoT_12 = 三数0,1,2;RoT_23 = 三数0,2,3;Ro_123 = 四个号0,1,2,3;RoCol1 = 线注 1,2,3,4,5,6;RoCol2 = 线注4,5,6,7,8,9 ;RoCol3 = 线注7,8,9,10,11,12;RoCol4 = 线注10,11,12,13,14,15;RoCol5 = 线注13,14,15,16,17,18;RoCol6 = 线注16,17,18,19,20,21;RoCol7 = 线注19,20,21,22,23,24;RoCol8 = 线注22,23,24,25,26,27;RoCol9 = 线注25,26,27,28,29,30;RoCol0 = 线注28,29,30,31,32,33;RoCola = 线注31,32,33,34,35,36;Ro1245 = 角注 1,2,4,5;Ro2356 = 角注2,3,5,6;Ro4578 = 角注4,5,7,8;Ro5689 = 角注5,6,8,9;Ro780a = 角注7,8,10,11;Ro89ab = 角注8,9,11,12;Ro0acd = 角注10,11,13,14;Roabde = 角注11,12,14,15;Rocdfg = 角注13,14,16,17;Rodegh = 角注14,15,17,18;Rofgij = 角注16,17,19,20;Roghjk = 角注17,18,20,21;Roijlm = 角注19,20,22,23;Rojkmn = 角注20,21,23,24;Rolmop = 角注22,23,25,26;Romnpq = 角注23,24,26,27;Rooprs = 角注25,26,28,29;Ropqst = 角注26,27,29,30;Rorsuv = 角注28,29,31,32;Rostvw = 角注29,30,32,33;Rouvxy = 角注31,32,34,35;Rovwyz = 角注32,33,35,36;RoT123 = 街注1,2,3 ;RoT456 = 街注4,5,6;RoT789 = 街注7,8,9;RoT0ab = 街注10,11,12;RoTcde = 街注13,14,15;RoTfgh = 街注16,17,18;RoTijk = 街注19,20,21;RoTlmn = 街注22,23,24;RoTopq = 街注25,26,27;RoTrst = 街注28,29,30;RoTuvw = 街注31,32,33;RoTxyz = 街注34,35,36;RoDu12 = 分注1,2;RoDu23 = 分注2,3;RoDu45 = 分注4,5;RoDu56 = 分注5,6;RoDu78 = 分注7,8;RoDu89 = 分注8,9;RoDu0a = 分注10,11;RoDuab = 分注11,12;RoDucd = 分注13,14;RoDude = 分注14,15;RoDufg = 分注16,17;RoDugh = 分注17,18;RoDuij = 分注19,20;RoDujk = 分注20,21;RoDulm = 分注22,23;RoDumn = 分注23,24;RoDuop = 分注25,26;RoDupq = 分注26,27;RoDurs = 分注28,29;RoDust = 分注29,30;RoDuuv = 分注31,32;RoDuvw = 分注32,33;RoDuxy = 分注34,35;RoDuyz = 分注35,36;RoDu_1 = 分注0,1;RoDu_2 = 分注0,2;RoDu_3 = 分注0,3;RoDu14 = 分注1,4;RoDu25 = 分注2,5;RoDu36 = 分注3,6;RoDu47 = 分注4,7;RoDu58 = 分注5,8;RoDu69 = 分注6,9;RoDu70 = 分注7,10;RoDu8a = 分注8,11;RoDu9b = 分注9,12;RoDu0c = 分注10,13;RoDuad = 分注11,14;RoDube = 分注12,15;RoDucf = 分注13,16;RoDudg = 分注14,17;RoDueh = 分注15,18;RoDufi = 分注16,19;RoDugj = 分注17,20;RoDuhk = 分注18,21;RoDuil = 分注19,22;RoDujm = 分注20,23;RoDukn = 分注21,24;RoDulo = 分注22,25;RoDump = 分注23,26;RoDunq = 分注24,27;RoDuor = 分注25,28;RoDups = 分注26,29;RoDuqt = 分注27,30;RoDuru = 分注28,31;RoDusv = 分注29,32;RoDutw = 分注30,33;RoDuux = 分注31,34;RoDuvy = 分注32,35;RoDuwz = 分注33,36;

## **骰宝**

**gameInfo解析说明**

骰宝的gameInfo中记录了发牌信息,字段用";"分隔,示例如下:

```
1;2;3
```

**字段解析说明**

| 示例  | 解析  | 说明                   |
| ----- | ----- | ---------------------- |
| 1;2;3 | 1;2;3 | 开彩骰子为:1点,2点,3点 |

**gameResult解析说明**

骰宝gameResult中记录了胜出的注点,同gameInfo

```
1;2;3
```

**betPoint解析说明**

骰宝betPoint 中记录了用户的下注金额和输赢金额,示例如下:

```
DiSm:1000.00@1000.00@1000.00#
```

对应示例解析说明:

注点名:下注金额@输赢额@洗码量#,多注点使用"#"分割

**注点明细:**

| 名称          | 说明            |
| ------------- | --------------- |
| DiTri0        | 全围骰          |
| DiTri1~DiTri6 | 围骰1~围骰6     |
| DiDou1~DiDou6 | 逢双1~逢双6     |
| DiTo04~DiTo17 | 4点~17点        |
| DiTw12~DiTw16 | 组合1-2~组合1-6 |
| DiTw23~DiTw26 | 组合2-3~组合2-6 |
| DiTw34~DiTw36 | 组合3-4~组合3-6 |
| DiTw45~DiTw46 | 组合4-5~组合4-6 |
| DiTw56        | 组合5-6         |
| DiOne1~DiOne6 | 单1~单6         |
| DiEven        | 双              |
| DiOdd         | 单              |
| DiBig         | 大              |
| DiSm          | 小              |

## **炸金花**

**gameInfo解析说明**

炸金花的gameInfo中记录了发牌信息,字段用";"分隔,示例如下:

```
2-3-0;5-2-1;2-2-2;5-4-3;5-3-4;11-3-5
```

**字段解析说明**

| 示例:2-3-0 | 解析         | 说明                                                        |
| ---------- | ------------ | ----------------------------------------------------------- |
| 2          | 2            | 牌的点数(1,2,3,4,5,6,7,8,9,10,11,12,13)                     |
| 3          | 梅花         | 牌的花色(1黑桃SPADE,2红心 HEART,3梅花CLUB,<br>4方块DIAMOND) |
| 0          | 第一张牌(龙) | 牌的位置(龙0,2,4；凤1,3,5)                                  |

**gameResult解析说明**

炸金花gameResult中记录了胜出的注点

```
PHOENIX
```

**字段解析说明**

| 名称    | 示例    | 说明                                    |
| ------- | ------- | --------------------------------------- |
| PHOENIX | PHOENIX | 龙凤和(DRAGON: 龙,PHOENIX: 凤,TILE: 和) |

**betPoint解析说明**

betPoint 中记录了用户的下注金额和输赢金额,示例如下:

```
PHOENIX:10.00@9.50@9.50#DRAGON:10.00@-10.00
```

对应示例解析说明:

注点名:下注金额@输赢额@洗码量#,多注点使用"#"分割

**注点明细:**

| 名称           | 说明    |
| -------------- | ------- |
| PHOENIX        | 凤      |
| DRAGON         | 龙      |
| PAIR8          | 对8以上 |
| FLUSH          | 同花    |
| STRAIGHT       | 顺子    |
| BOMB           | 豹子    |
| STRAIGHT_FLUSH | 同花顺  |

## HTTP状态码

| CODE | MESSAGE      | MESSAGE-EN  |
| :--- | ------------ | ----------- |
| 200  | 成功         | Success     |
| 400  | 参数不符     | Bad Request |
| 403  | 令牌验证失败 | UnAuth      |

## 状态码

| CODE   | MESSAGE              | MESSAGE-EN                 |
|:-------| -------------------- | -------------------------- |
| 0      | 成功                 | Success                    |
| -101   | 账号被停用           | Account Stop               |
| 202    | 渠道不符             | Invalid Channel            |
| 400    | 参数不符             | Bad Request                |
| 500    | 服务器异常           | Server error               |
| 602    | 用户已存在           | User Exists                |
| 603    | 用户状态有误         | Invalid User Status        |
| 624    | 余额不足             | Lack Of Balance            |
| 627    | 订单号重复           | Serial Repeat              |
| 630    | 数据已过期           | Data Expired               |
| 631    | 用户名包含关键字     | Username contains keywords |
| 1001   | 记录不存在           | Record not exists          |
| 1002   | 用户不存在           | User does not exist        |
| 100000 | 用户未注册           | User no register           |
| 100004 | 游戏未开通           | Game closed                |
| 100005 | 频繁调用             | FREQUENTLY_CALL            |
| 100006 | 短时间内登录次数过多 | FREQUENTLY_LOGIN           |
| 100007 | 服务器繁忙           | SERVER_BUSY                |
| 100008 | 代理名重复           | AGENT_NAME_REPEAT          |
| 100012 | 不支持该币种         | CURRENCY_NOT_SUPPORT       |
| 100019 | 代理名不存在         | AGENT_NOT_EXIST            |
| 100020 | 代理与渠道不匹配     | AGENT_COMPANY_MATCH        |
| 100021 | 金额过大超过阈值     | AMOUNT_GREATER             |
| 100022 | 用户最大可选3个限额  | LIMIT_GREATER              |
| 100023 | 限额编码错误  | LIMIT_CODE_ERROR              |

## 币种

| 代码   | 类型             |
| :----- | ---------------- |
| CNY    | 人民币           |
| USD    | 美元             |
| KRW    | 韩元             |
| HKD    | 港元             |
| AUD    | 澳元             |
| THB    | 泰铢             |
| VND    | 越南盾           |
| VND(K) | 越南盾(K)        |
| IDR    | 印尼盾           |
| IDR(K) | 印尼盾(K)        |
| MYR    | 马来西亚吉令     |
| INR    | 印度卢比         |
| MMK    | 缅甸基亚特       |
| KES    | 肯尼亚先令       |
| USDT   | 泰达币           |
| mETH   | 以太币           |
| mBTC   | 比特币           |
| BDT    | 孟加拉塔卡       |
| PHP    | 菲律宾披索       |
| GBP    | 英镑             |
| AED    | 迪拉姆           |
| TWD    | 新台币           |
| PKR    | 巴基斯坦卢比     |
| MXN    | 墨西哥币         |
| BRL    | 巴西币           |
| SGD    | 新加坡币         |
| CLP    | 智利比索         |
| PEN    | 秘鲁新索尔       |
| VES    | 委内瑞拉玻利瓦尔 |
| HNL    | 洪都拉斯伦皮拉   |
| CRC    | 哥斯大黎加       |
| GTQ    | 危地马拉格查尔   |
| TZS    | 坦桑尼亚先令     |
